@@ -23,6 +23,8 @@
 
 #include "pgapifunc.h"
 
+#include "secure_sscanf.h"
+
 #define	NULL_IF_NULL(a) ((a) ? ((const char *)(a)) : "(null)")
 CSTR	ENTRY_TEST = " @@@ ";
 
@@ -103,6 +105,7 @@ BOOL	setExtraOptions(ConnInfo *ci, const char *optstr, const char *format)
 {
 	UInt4	flag = 0, cnt;
 	char	dummy[2];
+	int	status = 0;
 
 	if (!format)
 	{
@@ -127,7 +130,8 @@ BOOL	setExtraOptions(ConnInfo *ci, const char *optstr, const char *format)
 			format = dec_format;
 	}
 
-	if (cnt = sscanf(optstr, format, &flag, dummy), cnt < 1) // format error
+	if (cnt = secure_sscanf(optstr, &status, format,
+				ARG_UINT(&flag), ARG_STR(&dummy, sizeof(dummy))), cnt < 1) // format error
 		return FALSE;
 	else if (cnt > 1) // format error
 		return FALSE;
@@ -301,16 +305,22 @@ makeConnectString(char *connect_string, const ConnInfo *ci, UWORD len)
 	char		xaOptStr[16];
 #endif
 	ssize_t		hlen, nlen, olen;
-	/*BOOL		abbrev = (len <= 400);*/
-	BOOL		abbrev = (len < 1024) || 0 < ci->force_abbrev_connstr;
+	BOOL		abbrev;
 	UInt4		flag;
 
+	if (len > MAX_CONNECT_STRING) {
+		len = MAX_CONNECT_STRING;
+	}
+
+	/*abbrev = (len <= 400);*/
+	abbrev = (len < 1024) || 0 < ci->force_abbrev_connstr;
+
 MYLOG(0, "%s row_versioning=%s\n", __FUNCTION__, ci->row_versioning);
 
 MYLOG(DETAIL_LOG_LEVEL, "force_abbrev=%d abbrev=%d\n", ci->force_abbrev_connstr, abbrev);
 	encode(ci->password, encoded_item, sizeof(encoded_item));
 	/* fundamental info */
-	nlen = MAX_CONNECT_STRING;
+	nlen = len;
 	olen = snprintf(connect_string, nlen, "%s=%s;DATABASE=%s;SERVER=%s;PORT=%s;UID=%s;PWD=%s",
 			got_dsn ? "DSN" : "DRIVER",
 			got_dsn ? ci->dsn : ci->drivername,
@@ -327,7 +337,7 @@ MYLOG(DETAIL_LOG_LEVEL, "force_abbrev=%d abbrev=%d\n", ci->force_abbrev_connstr,
 
 	/* extra info */
 	hlen = strlen(connect_string);
-	nlen = MAX_CONNECT_STRING - hlen;
+	nlen = len - hlen;
 MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 	if (!abbrev)
 	{
@@ -474,7 +484,7 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 				ABBR_SSLMODE "=%s", abbrev_sslmode(ci->sslmode, abbrevmode, sizeof(abbrevmode)));
 		}
 		hlen = strlen(connect_string);
-		nlen = MAX_CONNECT_STRING - hlen;
+		nlen = len - hlen;
 		olen = snprintf(&connect_string[hlen], nlen, ";"
 				"%s"		/* ABBR_CONNSETTINGS */
 				ABBR_FETCH "=%d;"
@@ -505,7 +515,7 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 		if (olen < nlen || ci->rollback_on_error >= 0)
 		{
 			hlen = strlen(connect_string);
-			nlen = MAX_CONNECT_STRING - hlen;
+			nlen = len - hlen;
 			/*
 			 * The PROTOCOL setting must be placed after CX flag
 			 * so that this option can override the CX setting.
@@ -525,7 +535,7 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 		if (0 != flag)
 		{
 			hlen = strlen(connect_string);
-			nlen = MAX_CONNECT_STRING - hlen;
+			nlen = len - hlen;
 			olen = snprintf(&connect_string[hlen], nlen, ";"
 				INI_EXTRAOPTIONS "=%x;",
 				flag);
@@ -545,19 +555,20 @@ unfoldCXAttribute(ConnInfo *ci, const char *value)
 {
 	int	count;
 	UInt4	flag;
+	int	status = 0;
 
 	if (strlen(value) < 2)
 	{
 		count = 3;
-		sscanf(value, "%x", &flag);
+		secure_sscanf(value, &status, "%x", ARG_UINT(&flag));
 	}
 	else
 	{
 		char	cnt[8];
 		memcpy(cnt, value, 2);
 		cnt[2] = '\0';
-		sscanf(cnt, "%x", &count);
-		sscanf(value + 2, "%x", &flag);
+		secure_sscanf(cnt, &status, "%x", ARG_UINT(&count));
+		secure_sscanf(value + 2, &status, "%x", ARG_UINT(&flag));
 	}
 	ci->allow_keyset = (char)((flag & BIT_UPDATABLECURSORS) != 0);
 	ci->lf_conversion = (char)((flag & BIT_LFCONVERSION) != 0);
@@ -653,7 +664,7 @@ copyConnAttributes(ConnInfo *ci, const char *attribute, const char *value)
 				*ptr = '\0';
 				/* ignore first part */
 			}
-			ci->rollback_on_error = atoi(ptr + 1);
+			ci->rollback_on_error = pg_atoi(ptr + 1);
 			MYLOG(0, "key='%s' value='%s' rollback_on_error=%d\n",
 				attribute, value, ci->rollback_on_error);
 			printed = TRUE;
@@ -681,31 +692,31 @@ copyConnAttributes(ConnInfo *ci, const char *attribute, const char *value)
 		ci->pqopt = decode_or_remove_braces(value);
 	}
 	else if (stricmp(attribute, INI_UPDATABLECURSORS) == 0 || stricmp(attribute, ABBR_UPDATABLECURSORS) == 0)
-		ci->allow_keyset = atoi(value);
+		ci->allow_keyset = pg_atoi(value);
 	else if (stricmp(attribute, INI_LFCONVERSION) == 0 || stricmp(attribute, ABBR_LFCONVERSION) == 0)
-		ci->lf_conversion = atoi(value);
+		ci->lf_conversion = pg_atoi(value);
 	else if (stricmp(attribute, INI_TRUEISMINUS1) == 0 || stricmp(attribute, ABBR_TRUEISMINUS1) == 0)
-		ci->true_is_minus1 = atoi(value);
+		ci->true_is_minus1 = pg_atoi(value);
 	else if (stricmp(attribute, INI_INT8AS) == 0)
-		ci->int8_as = atoi(value);
+		ci->int8_as = pg_atoi(value);
 	else if (stricmp(attribute, INI_NUMERIC_AS) == 0 || stricmp(attribute, ABBR_NUMERIC_AS) == 0)
-		ci->numeric_as = atoi(value);
+		ci->numeric_as = pg_atoi(value);
 	else if (stricmp(attribute, INI_BYTEAASLONGVARBINARY) == 0 || stricmp(attribute, ABBR_BYTEAASLONGVARBINARY) == 0)
-		ci->bytea_as_longvarbinary = atoi(value);
+		ci->bytea_as_longvarbinary = pg_atoi(value);
 	else if (stricmp(attribute, INI_USESERVERSIDEPREPARE) == 0 || stricmp(attribute, ABBR_USESERVERSIDEPREPARE) == 0)
-		ci->use_server_side_prepare = atoi(value);
+		ci->use_server_side_prepare = pg_atoi(value);
 	else if (stricmp(attribute, INI_LOWERCASEIDENTIFIER) == 0 || stricmp(attribute, ABBR_LOWERCASEIDENTIFIER) == 0)
-		ci->lower_case_identifier = atoi(value);
+		ci->lower_case_identifier = pg_atoi(value);
 	else if (stricmp(attribute, INI_KEEPALIVETIME) == 0 || stricmp(attribute, ABBR_KEEPALIVETIME) == 0)
-		ci->keepalive_idle = atoi(value);
+		ci->keepalive_idle = pg_atoi(value);
 	else if (stricmp(attribute, INI_KEEPALIVEINTERVAL) == 0 || stricmp(attribute, ABBR_KEEPALIVEINTERVAL) == 0)
-		ci->keepalive_interval = atoi(value);
+		ci->keepalive_interval = pg_atoi(value);
 	else if (stricmp(attribute, INI_BATCHSIZE) == 0 || stricmp(attribute, ABBR_BATCHSIZE) == 0)
-		ci->batch_size = atoi(value);
+		ci->batch_size = pg_atoi(value);
 	else if (stricmp(attribute, INI_OPTIONAL_ERRORS) == 0 || stricmp(attribute, ABBR_OPTIONAL_ERRORS) == 0)
-		ci->optional_errors = atoi(value);
+		ci->optional_errors = pg_atoi(value);
 	else if (stricmp(attribute, INI_IGNORETIMEOUT) == 0 || stricmp(attribute, ABBR_IGNORETIMEOUT) == 0)
-		ci->ignore_timeout = atoi(value);
+		ci->ignore_timeout = pg_atoi(value);
 	else if (stricmp(attribute, INI_SSLMODE) == 0 || stricmp(attribute, ABBR_SSLMODE) == 0)
 	{
 		switch (value[0])
@@ -745,20 +756,22 @@ copyConnAttributes(ConnInfo *ci, const char *attribute, const char *value)
 		unfoldCXAttribute(ci, value);
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 	else if (stricmp(attribute, INI_XAOPT) == 0)
-		ci->xa_opt = atoi(value);
+		ci->xa_opt = pg_atoi(value);
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
 	else if (stricmp(attribute, INI_EXTRAOPTIONS) == 0)
 	{
 		UInt4	val1 = 0, val2 = 0;
+		int		status = 0;
 
 		if ('+' == value[0])
 		{
-			sscanf(value + 1, "%x-%x", &val1, &val2);
+			secure_sscanf(value + 1, &status, "%x-%x",
+				ARG_UINT(&val1), ARG_UINT(&val2));
 			add_removeExtraOptions(ci, val1, val2);
 		}
 		else if ('-' == value[0])
 		{
-			sscanf(value + 1, "%x", &val2);
+			secure_sscanf(value + 1, &status, "%x", ARG_UINT(&val2));
 			add_removeExtraOptions(ci, 0, val2);
 		}
 		else
@@ -771,38 +784,38 @@ copyConnAttributes(ConnInfo *ci, const char *attribute, const char *value)
 	}
 
 	else if (stricmp(attribute, INI_FETCH) == 0 || stricmp(attribute, ABBR_FETCH) == 0)
-		ci->drivers.fetch_max = atoi(value);
+		ci->drivers.fetch_max = pg_atoi(value);
 	else if (stricmp(attribute, INI_DEBUG) == 0 || stricmp(attribute, ABBR_DEBUG) == 0)
-		ci->drivers.debug = atoi(value);
+		ci->drivers.debug = pg_atoi(value);
 	else if (stricmp(attribute, INI_COMMLOG) == 0 || stricmp(attribute, ABBR_COMMLOG) == 0)
-		ci->drivers.commlog = atoi(value);
+		ci->drivers.commlog = pg_atoi(value);
 	/*
 	 * else if (stricmp(attribute, INI_UNIQUEINDEX) == 0 ||
 	 * stricmp(attribute, "UIX") == 0) ci->drivers.unique_index =
-	 * atoi(value);
+	 * pg_atoi(value);
 	 */
 	else if (stricmp(attribute, INI_UNKNOWNSIZES) == 0 || stricmp(attribute, ABBR_UNKNOWNSIZES) == 0)
-		ci->drivers.unknown_sizes = atoi(value);
+		ci->drivers.unknown_sizes = pg_atoi(value);
 	else if (stricmp(attribute, INI_LIE) == 0)
-		ci->drivers.lie = atoi(value);
+		ci->drivers.lie = pg_atoi(value);
 	else if (stricmp(attribute, INI_PARSE) == 0 || stricmp(attribute, ABBR_PARSE) == 0)
-		ci->drivers.parse = atoi(value);
+		ci->drivers.parse = pg_atoi(value);
 	else if (stricmp(attribute, INI_USEDECLAREFETCH) == 0 || stricmp(attribute, ABBR_USEDECLAREFETCH) == 0)
-		ci->drivers.use_declarefetch = atoi(value);
+		ci->drivers.use_declarefetch = pg_atoi(value);
 	else if (stricmp(attribute, INI_MAXVARCHARSIZE) == 0 || stricmp(attribute, ABBR_MAXVARCHARSIZE) == 0)
-		ci->drivers.max_varchar_size = atoi(value);
+		ci->drivers.max_varchar_size = pg_atoi(value);
 	else if (stricmp(attribute, INI_MAXLONGVARCHARSIZE) == 0 || stricmp(attribute, ABBR_MAXLONGVARCHARSIZE) == 0)
-		ci->drivers.max_longvarchar_size = atoi(value);
+		ci->drivers.max_longvarchar_size = pg_atoi(value);
 	else if (stricmp(attribute, INI_TEXTASLONGVARCHAR) == 0 || stricmp(attribute, ABBR_TEXTASLONGVARCHAR) == 0)
-		ci->drivers.text_as_longvarchar = atoi(value);
+		ci->drivers.text_as_longvarchar = pg_atoi(value);
 	else if (stricmp(attribute, INI_UNKNOWNSASLONGVARCHAR) == 0 || stricmp(attribute, ABBR_UNKNOWNSASLONGVARCHAR) == 0)
-		ci->drivers.unknowns_as_longvarchar = atoi(value);
+		ci->drivers.unknowns_as_longvarchar = pg_atoi(value);
 	else if (stricmp(attribute, INI_BOOLSASCHAR) == 0 || stricmp(attribute, ABBR_BOOLSASCHAR) == 0)
-		ci->drivers.bools_as_char = atoi(value);
+		ci->drivers.bools_as_char = pg_atoi(value);
 	else if (stricmp(attribute, INI_EXTRASYSTABLEPREFIXES) == 0 || stricmp(attribute, ABBR_EXTRASYSTABLEPREFIXES) == 0)
 		STRCPY_FIXED(ci->drivers.extra_systable_prefixes, value);
 	else if (stricmp(attribute, INI_FETCHREFCURSORS) == 0 || stricmp(attribute, ABBR_FETCHREFCURSORS) == 0)
-		ci->fetch_refcursors = atoi(value);
+		ci->fetch_refcursors = pg_atoi(value);
 	else
 		found = FALSE;
 
@@ -976,9 +989,9 @@ MYLOG(0, "drivername=%s\n", drivername);
 
 	/* It's appropriate to handle debug and commlog here */
 	if (SQLGetPrivateProfileString(DSN, INI_DEBUG, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->drivers.debug = atoi(temp);
+		ci->drivers.debug = pg_atoi(temp);
 	if (SQLGetPrivateProfileString(DSN, INI_COMMLOG, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->drivers.commlog = atoi(temp);
+		ci->drivers.commlog = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_READONLY, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
 		STRCPY_FIXED(ci->onlyread, temp);
@@ -1003,7 +1016,7 @@ MYLOG(0, "drivername=%s\n", drivername);
 		if (ptr = strchr(temp, '-'), NULL != ptr)
 		{
 			*ptr = '\0';
-			ci->rollback_on_error = atoi(ptr + 1);
+			ci->rollback_on_error = pg_atoi(ptr + 1);
 			MYLOG(0, "rollback_on_error=%d\n", ci->rollback_on_error);
 		}
 	}
@@ -1052,53 +1065,53 @@ MYLOG(0, "drivername=%s\n", drivername);
 		STRCPY_FIXED(ci->translation_option, temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_UPDATABLECURSORS, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->allow_keyset = atoi(temp);
+		ci->allow_keyset = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_LFCONVERSION, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->lf_conversion = atoi(temp);
+		ci->lf_conversion = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_TRUEISMINUS1, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->true_is_minus1 = atoi(temp);
+		ci->true_is_minus1 = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_INT8AS, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->int8_as = atoi(temp);
+		ci->int8_as = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, ABBR_NUMERIC_AS, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->numeric_as = atoi(temp);
+		ci->numeric_as = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_OPTIONAL_ERRORS, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->optional_errors = atoi(temp);
+		ci->optional_errors = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_BYTEAASLONGVARBINARY, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->bytea_as_longvarbinary = atoi(temp);
+		ci->bytea_as_longvarbinary = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_USESERVERSIDEPREPARE, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->use_server_side_prepare = atoi(temp);
+		ci->use_server_side_prepare = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_LOWERCASEIDENTIFIER, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->lower_case_identifier = atoi(temp);
+		ci->lower_case_identifier = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_KEEPALIVETIME, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		if (0 == (ci->keepalive_idle = atoi(temp)))
+		if (0 == (ci->keepalive_idle = pg_atoi(temp)))
 			ci->keepalive_idle = -1;
 	if (SQLGetPrivateProfileString(DSN, INI_KEEPALIVEINTERVAL, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		if (0 == (ci->keepalive_interval = atoi(temp)))
+		if (0 == (ci->keepalive_interval = pg_atoi(temp)))
 			ci->keepalive_interval = -1;
 	if (SQLGetPrivateProfileString(DSN, INI_BATCHSIZE, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		if (0 == (ci->batch_size = atoi(temp)))
+		if (0 == (ci->batch_size = pg_atoi(temp)))
 			ci->batch_size = DEFAULT_BATCH_SIZE;
 	if (SQLGetPrivateProfileString(DSN, INI_IGNORETIMEOUT, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->ignore_timeout = atoi(temp);
+		ci->ignore_timeout = pg_atoi(temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_SSLMODE, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
 		STRCPY_FIXED(ci->sslmode, temp);
 
 	if (SQLGetPrivateProfileString(DSN, INI_FETCHREFCURSORS, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->fetch_refcursors = atoi(temp);
+		ci->fetch_refcursors = pg_atoi(temp);
 
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 	if (SQLGetPrivateProfileString(DSN, INI_XAOPT, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
-		ci->xa_opt = atoi(temp);
+		ci->xa_opt = pg_atoi(temp);
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
 
 	/* Force abbrev connstr or bde */
@@ -1106,8 +1119,9 @@ MYLOG(0, "drivername=%s\n", drivername);
 					temp, sizeof(temp), ODBC_INI) > 0)
 	{
 		UInt4	val = 0;
+		int 	status = 0;
 
-		sscanf(temp, "%x", &val);
+		secure_sscanf(temp, &status, "%x", ARG_UINT(&val));
 		replaceExtraOptions(ci, val, TRUE);
 		MYLOG(0, "force_abbrev=%d bde=%d cvt_null_date=%d\n", ci->force_abbrev_connstr, ci->bde_environment, ci->cvt_null_date_string);
 	}
@@ -1430,59 +1444,59 @@ get_Ci_Drivers(const char *section, const char *filename, GLOBAL_VALUES *comval)
 	if (SQLGetPrivateProfileString(section, INI_FETCH, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
 	{
-		if (atoi(temp) > 0)
-			comval->fetch_max = atoi(temp);
+		if (pg_atoi(temp) > 0)
+			comval->fetch_max = pg_atoi(temp);
 	}
 
 	/* Recognize Unique Index is stored in the driver section only */
 	if (SQLGetPrivateProfileString(section, INI_UNIQUEINDEX, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->unique_index = atoi(temp);
+		comval->unique_index = pg_atoi(temp);
 
 	/* Unknown Sizes is stored in the driver section only */
 	if (SQLGetPrivateProfileString(section, INI_UNKNOWNSIZES, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->unknown_sizes = atoi(temp);
+		comval->unknown_sizes = pg_atoi(temp);
 
 	/* Lie about supported functions? */
 	if (SQLGetPrivateProfileString(section, INI_LIE, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->lie = atoi(temp);
+		comval->lie = pg_atoi(temp);
 
 	/* Parse statements */
 	if (SQLGetPrivateProfileString(section, INI_PARSE, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->parse = atoi(temp);
+		comval->parse = pg_atoi(temp);
 
 	/* UseDeclareFetch is stored in the driver section only */
 	if (SQLGetPrivateProfileString(section, INI_USEDECLAREFETCH, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->use_declarefetch = atoi(temp);
+		comval->use_declarefetch = pg_atoi(temp);
 
 	/* Max Varchar Size */
 	if (SQLGetPrivateProfileString(section, INI_MAXVARCHARSIZE, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->max_varchar_size = atoi(temp);
+		comval->max_varchar_size = pg_atoi(temp);
 
 	/* Max TextField Size */
 	if (SQLGetPrivateProfileString(section, INI_MAXLONGVARCHARSIZE, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->max_longvarchar_size = atoi(temp);
+		comval->max_longvarchar_size = pg_atoi(temp);
 
 	/* Text As LongVarchar	*/
 	if (SQLGetPrivateProfileString(section, INI_TEXTASLONGVARCHAR, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->text_as_longvarchar = atoi(temp);
+		comval->text_as_longvarchar = pg_atoi(temp);
 
 	/* Unknowns As LongVarchar	*/
 	if (SQLGetPrivateProfileString(section, INI_UNKNOWNSASLONGVARCHAR, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->unknowns_as_longvarchar = atoi(temp);
+		comval->unknowns_as_longvarchar = pg_atoi(temp);
 
 	/* Bools As Char */
 	if (SQLGetPrivateProfileString(section, INI_BOOLSASCHAR, NULL_STRING,
 				temp, sizeof(temp), filename) > 0)
-		comval->bools_as_char = atoi(temp);
+		comval->bools_as_char = pg_atoi(temp);
 
 	/* Extra Systable prefixes */
 
@@ -1783,7 +1797,7 @@ CC_conninfo_init(ConnInfo *conninfo, UInt4 option)
 
 	if (0 != (CLEANUP_FOR_REUSE & option))
 		CC_conninfo_release(conninfo);
-	memset(conninfo, 0, sizeof(ConnInfo));
+	pg_memset(conninfo, 0, sizeof(ConnInfo));
 
 	conninfo->allow_keyset = -1;
 	conninfo->lf_conversion = -1;
@@ -1818,7 +1832,7 @@ CC_conninfo_init(ConnInfo *conninfo, UInt4 option)
 
 void	init_globals(GLOBAL_VALUES *glbv)
 {
-	memset(glbv, 0, sizeof(*glbv));
+	pg_memset(glbv, 0, sizeof(*glbv));
 	glbv->debug = -1;
 	glbv->commlog = -1;
 }
@@ -1828,7 +1842,7 @@ void	init_globals(GLOBAL_VALUES *glbv)
 
 void	copy_globals(GLOBAL_VALUES *to, const GLOBAL_VALUES *from)
 {
-	memset(to, 0, sizeof(*to));
+	pg_memset(to, 0, sizeof(*to));
 	/***
 	memcpy(to, from, sizeof(GLOBAL_VALUES));
 	SET_NAME_DIRECTLY(to->drivername, NULL);
@@ -1866,7 +1880,7 @@ void	finalize_globals(GLOBAL_VALUES *glbv)
 void
 CC_copy_conninfo(ConnInfo *ci, const ConnInfo *sci)
 {
-	memset(ci, 0,sizeof(ConnInfo));
+	pg_memset(ci, 0,sizeof(ConnInfo));
 
 	CORR_STRCPY(dsn);
 	CORR_STRCPY(desc);
