@@ -33,7 +33,16 @@
 #include "lobj.h"
 #include "pgapifunc.h"
 
-/*		Perform a Prepare on the SQL statement */
+#include "secure_sscanf.h"
+
+/** 
+ * @brief Perform a Prepare on the SQL statement 
+ * 
+ * @param hstmt		Handle to the statement
+ * @param szSqlStr	SQL statement
+ * @param cbSqlStr	Length of the SQL statement
+ * 
+ */
 RETCODE		SQL_API
 PGAPI_Prepare(HSTMT hstmt,
 			  const SQLCHAR * szSqlStr,
@@ -133,7 +142,14 @@ MYLOG(DETAIL_LOG_LEVEL, "leaving %d\n", retval);
 }
 
 
-/*		Performs the equivalent of SQLPrepare, followed by SQLExecute. */
+/** 
+ * 	Performs the equivalent of SQLPrepare, followed by SQLExecute. 
+ *	@param hstmt		Handle to the statement
+ *	@param szSqlStr		SQL statement
+ *	@param cbSqlStr	Length of the SQL statement
+ *	@param flag			Flags to control the execution of the statement
+ * 
+*/
 RETCODE		SQL_API
 PGAPI_ExecDirect(HSTMT hstmt,
 				 const SQLCHAR * szSqlStr,
@@ -393,6 +409,15 @@ int HowToPrepareBeforeExec(StatementClass *stmt, BOOL checkOnly)
 	return nCallParse;
 }
 
+/**
+ * 	Generate a name for the SVP (Savepoint) for the given
+ * 	connection.
+ *
+ * 	@param	conn	The connection.
+ * 	@param	wrk	The buffer to store the name in.
+ * 	@param	wrksize	The size of the buffer.
+ * 	@return		The name of the Savepoint.
+ */
 static
 const char *GetSvpName(const ConnectionClass *conn, char *wrk, int wrksize)
 {
@@ -404,8 +429,8 @@ const char *GetSvpName(const ConnectionClass *conn, char *wrk, int wrksize)
  *	The execution after all parameters were resolved.
  */
 
-#define INVALID_EXPBUFFER	PQExpBufferDataBroken(stmt->stmt_deffered)
-#define VALID_EXPBUFFER	(!PQExpBufferDataBroken(stmt->stmt_deffered))
+#define INVALID_EXPBUFFER	PQExpBufferDataBroken(stmt->stmt_deferred)
+#define VALID_EXPBUFFER	(!PQExpBufferDataBroken(stmt->stmt_deferred))
 
 static
 void param_status_batch_update(IPDFields *ipdopts, RETCODE retval, SQLLEN target_row, int count_of_deffered)
@@ -438,7 +463,7 @@ RETCODE	Exec_with_parameters_resolved(StatementClass *stmt, EXEC_TYPE exec_type,
 	BOOL		prepare_before_exec = FALSE;
 	char *stmt_with_params;
 	SQLLEN		status_row = stmt->exec_current_row;
-	int		count_of_deffered;
+	int		count_of_deferred;
 
 	*exec_end = FALSE;
 	conn = SC_get_conn(stmt);
@@ -465,7 +490,7 @@ MYLOG(DETAIL_LOG_LEVEL, "prepare_before_exec=%d srv=%d\n", prepare_before_exec,
 			stmt_with_params = stmt->stmt_with_params = NULL;
 		}
 		if (INVALID_EXPBUFFER ||
-		    !stmt->stmt_deffered.data[0])
+		    !stmt->stmt_deferred.data[0])
 			RETURN(SQL_SUCCESS);
 	}
 	else
@@ -512,7 +537,7 @@ MYLOG(0, "about to begin SC_execute exec_type=%d\n", exec_type);
 			}
 		}
 	}
-	count_of_deffered = stmt->count_of_deffered;
+	count_of_deferred = stmt->count_of_deffered;
 	if (DIRECT_EXEC == exec_type)
 	{
 		retval = SC_execute(stmt);
@@ -523,7 +548,7 @@ MYLOG(0, "about to begin SC_execute exec_type=%d\n", exec_type);
 		 stmt->count_of_deffered + 1 < stmt->batch_size)
 	{
 		if (INVALID_EXPBUFFER)
-			initPQExpBuffer(&stmt->stmt_deffered);
+			initPQExpBuffer(&stmt->stmt_deferred);
 		if (INVALID_EXPBUFFER)
 		{
 			retval = SQL_ERROR;
@@ -533,10 +558,10 @@ MYLOG(0, "about to begin SC_execute exec_type=%d\n", exec_type);
 		{
 			if (NULL != stmt_with_params)
 			{
-				if (stmt->stmt_deffered.data[0])
-					appendPQExpBuffer(&stmt->stmt_deffered, ";%s", stmt_with_params);
+				if (stmt->stmt_deferred.data[0])
+					appendPQExpBuffer(&stmt->stmt_deferred, ";%s", stmt_with_params);
 				else
-					printfPQExpBuffer(&stmt->stmt_deffered, "%s", stmt_with_params);
+					printfPQExpBuffer(&stmt->stmt_deferred, "%s", stmt_with_params);
 			}
 			if (NULL != ipdopts->param_status_ptr)
 				ipdopts->param_status_ptr[stmt->exec_current_row] = SQL_PARAM_SUCCESS; // set without exec
@@ -550,19 +575,19 @@ MYLOG(0, "about to begin SC_execute exec_type=%d\n", exec_type);
 		if (VALID_EXPBUFFER)
 		{
 			if (NULL != stmt_with_params)
-				appendPQExpBuffer(&stmt->stmt_deffered, ";%s", stmt_with_params);
-			stmt->stmt_with_params = stmt->stmt_deffered.data;
+				appendPQExpBuffer(&stmt->stmt_deferred, ";%s", stmt_with_params);
+			stmt->stmt_with_params = stmt->stmt_deferred.data;
 		}
 		retval = SC_execute(stmt);
 		stmt->stmt_with_params = stmt_with_params;
 		stmt->count_of_deffered = 0;
 		if (VALID_EXPBUFFER)
-			resetPQExpBuffer(&stmt->stmt_deffered);
+			resetPQExpBuffer(&stmt->stmt_deferred);
 	}
 	if (retval == SQL_ERROR)
 	{
-MYLOG(0, "count_of_deffered=%d\n", count_of_deffered);
-		param_status_batch_update(ipdopts, SQL_PARAM_ERROR, stmt->exec_current_row, count_of_deffered);
+MYLOG(0, "count_of_deferred=%d\n", count_of_deferred);
+		param_status_batch_update(ipdopts, SQL_PARAM_ERROR, stmt->exec_current_row, count_of_deferred);
 		stmt->exec_current_row = -1;
 		*exec_end = TRUE;
 		RETURN(retval)
@@ -593,11 +618,11 @@ MYLOG(0, "count_of_deffered=%d\n", count_of_deffered);
 				ipdopts->param_status_ptr[status_row] = SQL_PARAM_SUCCESS;
 				break;
 			case SQL_SUCCESS_WITH_INFO:
-MYLOG(0, "count_of_deffered=%d has_notice=%d\n", count_of_deffered, stmt->has_notice);
-				param_status_batch_update(ipdopts, (count_of_deffered > 0 && !stmt->has_notice) ? SQL_PARAM_SUCCESS : SQL_PARAM_SUCCESS_WITH_INFO, status_row, count_of_deffered);
+MYLOG(0, "count_of_deffered=%d has_notice=%d\n", count_of_deferred, stmt->has_notice);
+				param_status_batch_update(ipdopts, (count_of_deferred > 0 && !stmt->has_notice) ? SQL_PARAM_SUCCESS : SQL_PARAM_SUCCESS_WITH_INFO, status_row, count_of_deferred);
 				break;
 			default:
-				param_status_batch_update(ipdopts, SQL_PARAM_ERROR, status_row, count_of_deffered);
+				param_status_batch_update(ipdopts, SQL_PARAM_ERROR, status_row, count_of_deferred);
 				break;
 		}
 	}
@@ -620,11 +645,12 @@ MYLOG(0, "count_of_deffered=%d has_notice=%d\n", count_of_deffered, stmt->has_no
 		    NULL != env &&
 		    EN_is_odbc3(env))
 		{
-			int     count;
+			int	count;
+			int	status = 0;
 
-			if (sscanf(cmd , "UPDATE %d", &count) == 1)
+			if (secure_sscanf(cmd, &status, "UPDATE %d", ARG_INT(&count)) == 1)
 				;
-			else if (sscanf(cmd , "DELETE %d", &count) == 1)
+			else if (secure_sscanf(cmd, &status, "DELETE %d", ARG_INT(&count)) == 1)
 				;
 			else
 				count = -1;
@@ -651,6 +677,12 @@ cleanup:
 	return retval;
 }
 
+/**
+ * @param[in] stmt 
+ * @return
+ *		1: transaction rollback
+ *		2: statement rollback
+ */
 int
 StartRollbackState(StatementClass *stmt)
 {
@@ -665,6 +697,7 @@ MYLOG(DETAIL_LOG_LEVEL, "entering %p->external=%d\n", stmt, stmt->external);
 
 	if (!ci || ci->rollback_on_error < 0) /* default */
 	{
+		/* server version greater than or equal to 8.0 ?*/
 		if (conn && PG_VERSION_GE(conn, 8.0))
 			ret = 2; /* statement rollback */
 		else
@@ -689,6 +722,20 @@ MYLOG(DETAIL_LOG_LEVEL, "entering %p->external=%d\n", stmt, stmt->external);
 	return	ret;
 }
 
+/**
+ * @param[in] *conn
+ * @param[in] type
+ * 	INTERNAL_SAVEPOINT_OPERATION or INTERNAL_ROLLBACK_OPERATION
+ * 	if type is INTERNAL_SAVEPOINT_OPERATION and conn->internal_svp is FALSE
+ * 	then the command is "SAVEPOINT" instead of "RELEASE SAVEPOINT"
+ *  if type is INTERNAL_ROLLBACK_OPERATION and conn->internal_svp is FALSE
+ * 	then the command is "ROLLBACK" instead of "ROLLBACK TO SAVEPOINT"
+ * @param[out] *cmd
+ * 	buffer to hold command to be sent
+ * @param[in] buflen
+ * @return less than zero if an error or number of characters in command
+ * 
+ */
 int
 GenerateSvpCommand(ConnectionClass *conn, int type, char *cmd, int buflen)
 {
@@ -790,6 +837,14 @@ MYLOG(DETAIL_LOG_LEVEL, "leaving %p->accessed=%d\n", conn, CC_accessed_db(conn))
 	return ret;
 }
 
+
+/**
+ *  @brief Discards the statement savepoint
+ *  @param stmt 
+ *  @param ret 
+ *  @param errorOnly 
+ *  @return ret
+*/
 RETCODE
 DiscardStatementSvp(StatementClass *stmt, RETCODE ret, BOOL errorOnly)
 {
@@ -920,7 +975,13 @@ SC_setInsertedTable(StatementClass *stmt, RETCODE retval)
 		NULL_THE_NAME(conn->schemaIns);
 }
 
-/*	Execute a prepared SQL statement */
+/** 
+ * @brief Execute a prepared SQL statement 
+ * @param hstmt
+ * @param flag
+ * @return SQL_SUCCESS if successful
+ *  
+*/
 RETCODE		SQL_API
 PGAPI_Execute(HSTMT hstmt, UWORD flag)
 {
