@@ -23,6 +23,29 @@
 #include "misc.h"
 
 
+/*
+ * SQLGetStmtAttrW
+ *
+ * Description:
+ *      This function retrieves the current setting of a statement attribute.
+ *      This is the Unicode (wide-character) version of SQLGetStmtAttr.
+ *
+ * Parameters:
+ *      hstmt - Handle to the statement
+ *      fAttribute - The attribute to retrieve (SQL_ATTR_* constant)
+ *      rgbValue - Buffer to store the attribute value
+ *      cbValueMax - Length of the rgbValue buffer in bytes
+ *      pcbValue - Pointer to store the actual length of string data
+ *
+ * Returns:
+ *      SQL_SUCCESS, SQL_SUCCESS_WITH_INFO, SQL_ERROR, or SQL_INVALID_HANDLE
+ *
+ * Comments:
+ *      Unlike some other Unicode functions, this function doesn't need to perform
+ *      character set conversion since statement attributes are not string-based
+ *      or already handle Unicode conversion internally. It simply passes through
+ *      to the core implementation function PGAPI_GetStmtAttr.
+ */
 RETCODE	SQL_API
 SQLGetStmtAttrW(SQLHSTMT hstmt,
 				SQLINTEGER	fAttribute,
@@ -34,16 +57,46 @@ SQLGetStmtAttrW(SQLHSTMT hstmt,
 	StatementClass	*stmt = (StatementClass *) hstmt;
 
 	MYLOG(0, "Entering\n");
+
 	ENTER_STMT_CS((StatementClass *) hstmt);
+
 	SC_clear_error((StatementClass *) hstmt);
+
+	/* Set up savepoint for transaction safety */
 	StartRollbackState(stmt);
+
 	ret = PGAPI_GetStmtAttr(hstmt, fAttribute, rgbValue,
 		cbValueMax, pcbValue);
+
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
+
 	LEAVE_STMT_CS((StatementClass *) hstmt);
+
 	return ret;
 }
 
+/*
+ * SQLSetStmtAttrW
+ *
+ * Description:
+ *      This function sets the current setting of a statement attribute.
+ *      This is the Unicode (wide-character) version of SQLSetStmtAttr.
+ *
+ * Parameters:
+ *      hstmt - Handle to the statement
+ *      fAttribute - The attribute to set (SQL_ATTR_* constant)
+ *      rgbValue - The value to set for the attribute
+ *      cbValueMax - Length of the rgbValue buffer in bytes (for string data)
+ *
+ * Returns:
+ *      SQL_SUCCESS, SQL_SUCCESS_WITH_INFO, SQL_ERROR, or SQL_INVALID_HANDLE
+ *
+ * Comments:
+ *      Unlike some other Unicode functions, this function doesn't need to perform
+ *      character set conversion since statement attributes are not string-based
+ *      or already handle Unicode conversion internally. It simply passes through
+ *      to the core implementation function PGAPI_SetStmtAttr.
+ */
 RETCODE SQL_API
 SQLSetStmtAttrW(SQLHSTMT hstmt,
 				SQLINTEGER	fAttribute,
@@ -54,13 +107,21 @@ SQLSetStmtAttrW(SQLHSTMT hstmt,
 	StatementClass	*stmt = (StatementClass *) hstmt;
 
 	MYLOG(0, "Entering\n");
+
 	ENTER_STMT_CS(stmt);
+
 	SC_clear_error(stmt);
+
+	/* Set up savepoint for transaction safety */
 	StartRollbackState(stmt);
+
 	ret = PGAPI_SetStmtAttr(hstmt, fAttribute, rgbValue,
 		cbValueMax);
+
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
+
 	LEAVE_STMT_CS(stmt);
+
 	return ret;
 }
 
@@ -103,7 +164,27 @@ SQLSetConnectAttrW(HDBC hdbc,
 	return ret;
 }
 
-/*      new function */
+/*
+ * SQLSetDescFieldW
+ *
+ * Description:
+ *      This function sets the value of a field in a descriptor record.
+ *      This is the Unicode (wide-character) version of SQLSetDescField.
+ *
+ * Parameters:
+ *      DescriptorHandle - Handle to the descriptor
+ *      RecNumber - The descriptor record number (1-based, 0 for header fields)
+ *      FieldIdentifier - The field identifier (SQL_DESC_* constant)
+ *      Value - The value to set for the field
+ *      BufferLength - Length of the Value buffer in bytes (for string data)
+ *
+ * Returns:
+ *      SQL_SUCCESS, SQL_SUCCESS_WITH_INFO, SQL_ERROR, or SQL_INVALID_HANDLE
+ *
+ * Comments:
+ *      This function handles Unicode to UTF-8 conversion for string fields
+ *      before calling the core implementation function PGAPI_SetDescField.
+ */
 RETCODE  SQL_API
 SQLSetDescFieldW(SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber,
 				 SQLSMALLINT FieldIdentifier, PTR Value,
@@ -111,10 +192,12 @@ SQLSetDescFieldW(SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber,
 {
 	RETCODE	ret;
 	SQLLEN	vallen;
-        char    *uval = NULL;
+    char    *uval = NULL;
 	BOOL	val_alloced = FALSE;
 
 	MYLOG(0, "Entering\n");
+
+	/* Convert Unicode strings to UTF-8 for specific string fields */
 	if (BufferLength > 0 || SQL_NTS == BufferLength)
 	{
 		switch (FieldIdentifier)
@@ -135,15 +218,21 @@ SQLSetDescFieldW(SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber,
 			break;
 		}
 	}
+
+	/* For non-string fields or if conversion wasn't needed, use the original value */
 	if (!val_alloced)
 	{
 		uval = Value;
 		vallen = BufferLength;
 	}
+
 	ret = PGAPI_SetDescField(DescriptorHandle, RecNumber, FieldIdentifier,
 				uval, (SQLINTEGER) vallen);
+
+	/* Free the converted string if we allocated one */
 	if (val_alloced)
 		free(uval);
+
 	return ret;
 }
 
@@ -417,7 +506,29 @@ SQLGetDiagFieldW(SQLSMALLINT	fHandleType,
 	return ret;
 }
 
-/*	new function */
+/*
+ * SQLGetDescRecW
+ *
+ * Description:
+ *      This function retrieves the current settings or values of fields in a descriptor record.
+ *      It's the wide-character (Unicode) version of SQLGetDescRec.
+ *
+ * Parameters:
+ *      DescriptorHandle - Handle to the descriptor
+ *      RecNumber - The descriptor record number (1-based)
+ *      Name - Buffer to store the descriptor name (Unicode)
+ *      BufferLength - Length of the Name buffer in characters
+ *      StringLength - Pointer to store the actual length of the name
+ *      Type - Pointer to store the SQL data type
+ *      SubType - Pointer to store the data type subcode
+ *      Length - Pointer to store the data length
+ *      Precision - Pointer to store the numeric precision
+ *      Scale - Pointer to store the numeric scale
+ *      Nullable - Pointer to store the nullability attribute
+ *
+ * Returns:
+ *      SQL_SUCCESS, SQL_SUCCESS_WITH_INFO, SQL_ERROR, or SQL_INVALID_HANDLE
+ */
 RETCODE		SQL_API
 SQLGetDescRecW(SQLHDESC DescriptorHandle,
 			  SQLSMALLINT RecNumber, SQLWCHAR *Name,
@@ -427,39 +538,78 @@ SQLGetDescRecW(SQLHDESC DescriptorHandle,
 			  SQLSMALLINT *Scale, SQLSMALLINT *Nullable)
 {
 	RETCODE		ret;
-	char		*NameA = NULL;
-	SQLSMALLINT	nlen;
+	char		*NameA = NULL;  /* Temporary buffer for ANSI version of name */
+	SQLSMALLINT	nlen;          /* Length of the name string */
 
 	MYLOG(0, "Entering h=%p rec=%d name=%p blen=%d\n", DescriptorHandle, RecNumber, Name, BufferLength);
 	MYLOG(0, "str=%p type=%p sub=%p len=%p prec=%p scale=%p null=%p\n", StringLength, Type, SubType, Length, Precision, Scale, Nullable);
 
+	/* Allocate temporary buffer for ANSI version if buffer length is provided */
 	if (BufferLength > 0)
 		NameA = malloc(BufferLength);
 
+	/* Call the core implementation with ANSI parameters */
 	ret = PGAPI_GetDescRec(DescriptorHandle, RecNumber, (SQLCHAR *) NameA, BufferLength,
 			&nlen, Type, SubType, Length, Precision,
 			Scale, Nullable);
+
 	if (SQL_SUCCEEDED(ret))
 	{
+		/* Convert ANSI name to Unicode if we have a valid name and buffer */
 		if (NameA && nlen <= BufferLength)
 		{
+			/* Try UTF-8 to UCS-2 conversion first */
 			SQLULEN ulen = utf8_to_ucs2_lf(NameA, nlen, FALSE, Name, BufferLength, TRUE);
+
 			if (ulen == (SQLULEN) -1)
+				/* Fall back to locale-based conversion if UTF-8 conversion fails */
 				nlen = (SQLSMALLINT) locale_to_sqlwchar((SQLWCHAR *) Name, NameA, BufferLength, FALSE);
 			else
 				nlen = (SQLSMALLINT) ulen;
+
+			/* If the name was truncated, return success with info */
 			if (nlen >= BufferLength)
 				ret = SQL_SUCCESS_WITH_INFO;
 		}
+
+		/* Return the actual string length if the caller wants it */
 		if (StringLength)
 			*StringLength = nlen;
 	}
+
+	/* Clean up the temporary buffer */
 	if (NameA)
 		free(NameA);
+
 	return ret;
 }
 
-/*	new function */
+/*
+ * SQLSetDescRecW
+ *
+ * Description:
+ *      This function sets multiple descriptor fields with a single call.
+ *      This is the Unicode (wide-character) version of SQLSetDescRec.
+ *
+ * Parameters:
+ *      DescriptorHandle - Handle to the descriptor
+ *      RecNumber - The descriptor record number (1-based)
+ *      Type - SQL data type
+ *      SubType - Datetime or interval subcode
+ *      Length - Maximum data length
+ *      Precision - Precision of numeric types
+ *      Scale - Scale of numeric types
+ *      Data - Pointer to data buffer (Unicode)
+ *      StringLength - Pointer to buffer length
+ *      Indicator - Pointer to indicator variable
+ *
+ * Returns:
+ *      SQL_SUCCESS, SQL_SUCCESS_WITH_INFO, SQL_ERROR, or SQL_INVALID_HANDLE
+ *
+ * Comments:
+ *      This function handles Unicode to UTF-8 conversion for string data
+ *      before calling the core implementation function PGAPI_SetDescRec.
+ */
 RETCODE		SQL_API
 SQLSetDescRecW(SQLHDESC DescriptorHandle,
 			  SQLSMALLINT RecNumber, SQLSMALLINT Type,
@@ -475,21 +625,29 @@ SQLSetDescRecW(SQLHDESC DescriptorHandle,
 
 	MYLOG(0, "Entering h=%p rec=%d type=%d sub=%d len=" FORMAT_LEN " prec=%d scale=%d data=%p\n", DescriptorHandle, RecNumber, Type, SubType, Length, Precision, Scale, Data);
 	MYLOG(0, "str=%p ind=%p\n", StringLength, Indicator);
-	
+
+	/* Convert Unicode string to UTF-8 if needed */
 	if (Length > 0 || SQL_NTS == Length)
 	{
 		uval = ucs2_to_utf8(Data, Length > 0 ? Length / WCLEN : Length, &vallen, FALSE);
 		val_alloced = TRUE;
 	}
+
+	/* For non-string data or if conversion wasn't needed, use the original value */
 	if (!val_alloced)
 	{
 		uval = Data;
 		vallen = Length;
 	}
+
+	/* Call the core implementation function */
 	ret = PGAPI_SetDescRec(DescriptorHandle, RecNumber, Type,
 			SubType, Length, Precision, Scale, uval,
 			&vallen, Indicator);
+
+	/* Free the converted string if we allocated one */
 	if (val_alloced)
 		free(uval);
+
 	return ret;
 }
